#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-prelude
version:              1.4.3
visibility:           public
id:                   clash-prelude-1.4.3-KR9rpKHRl4oCqgtezBTxwo
key:                  clash-prelude-1.4.3-KR9rpKHRl4oCqgtezBTxwo
license:              BSD-2-Clause
copyright:
    Copyright © 2013-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - Prelude library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Prelude library containing datatypes and functions for circuit design

    To use the library:

    * Import "Clash.Prelude"

    * Alternatively, if you want to explicitly route clock and reset ports,
    for more straightforward multi-clock designs, you can import the
    "Clash.Explicit.Prelude" module. Note that you should not import
    "Clash.Prelude" and "Clash.Explicit.Prelude" at the same time as they
    have overlapping definitions.

    A preliminary version of a tutorial can be found in "Clash.Tutorial", for a
    general overview of the library you should however check out "Clash.Prelude".
    Some circuit examples can be found in "Clash.Examples".

category:             Hardware
abi:                  f3bf90ff8b4c43a49f78fa1f5d8a5774
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation
    Clash.Annotations.BitRepresentation.Deriving
    Clash.Annotations.BitRepresentation.Internal
    Clash.Annotations.BitRepresentation.Util
    Clash.Annotations.Primitive Clash.Annotations.SynthesisAttributes
    Clash.Annotations.TH Clash.Annotations.TopEntity
    Clash.Class.AutoReg Clash.Class.BitPack Clash.Class.Exp
    Clash.Class.HasDomain Clash.Class.HasDomain.CodeGen
    Clash.Class.HasDomain.Common Clash.Class.HasDomain.HasSingleDomain
    Clash.Class.HasDomain.HasSpecificDomain Clash.Class.Num
    Clash.Class.Parity Clash.Class.Resize Clash.Clocks
    Clash.Clocks.Deriving Clash.Examples Clash.Explicit.BlockRam
    Clash.Explicit.BlockRam.File Clash.Explicit.DDR
    Clash.Explicit.Mealy Clash.Explicit.Moore Clash.Explicit.Prelude
    Clash.Explicit.Prelude.Safe Clash.Explicit.RAM Clash.Explicit.ROM
    Clash.Explicit.ROM.File Clash.Explicit.Reset Clash.Explicit.Signal
    Clash.Explicit.Signal.Delayed Clash.Explicit.SimIO
    Clash.Explicit.Synchronizer Clash.Explicit.Testbench
    Clash.Explicit.Verification Clash.HaskellPrelude Clash.Hidden
    Clash.Intel.ClockGen Clash.Intel.DDR Clash.Magic Clash.NamedTypes
    Clash.Prelude Clash.Prelude.BitIndex Clash.Prelude.BitReduction
    Clash.Prelude.BlockRam Clash.Prelude.BlockRam.File
    Clash.Prelude.DataFlow Clash.Prelude.Mealy Clash.Prelude.Moore
    Clash.Prelude.RAM Clash.Prelude.ROM Clash.Prelude.ROM.File
    Clash.Prelude.Safe Clash.Prelude.Testbench Clash.Promoted.Nat
    Clash.Promoted.Nat.Literals Clash.Promoted.Nat.TH
    Clash.Promoted.Nat.Unsafe Clash.Promoted.Symbol Clash.Signal
    Clash.Signal.BiSignal Clash.Signal.Bundle Clash.Signal.Delayed
    Clash.Signal.Delayed.Bundle Clash.Signal.Delayed.Internal
    Clash.Signal.Internal Clash.Signal.Internal.Ambiguous
    Clash.Signal.Trace Clash.Sized.BitVector Clash.Sized.Fixed
    Clash.Sized.Index Clash.Sized.Internal.BitVector
    Clash.Sized.Internal.Index Clash.Sized.Internal.Mod
    Clash.Sized.Internal.Signed Clash.Sized.Internal.Unsigned
    Clash.Sized.RTree Clash.Sized.Signed Clash.Sized.Unsigned
    Clash.Sized.Vector Clash.Tutorial Clash.Verification
    Clash.Verification.DSL Clash.Verification.Internal
    Clash.Verification.PrettyPrinters Clash.XException
    Clash.XException.Internal Clash.XException.TH Clash.Xilinx.ClockGen
    Clash.Xilinx.DDR

hidden-modules:
    Clash.Class.AutoReg.Instances Clash.Class.AutoReg.Internal
    Clash.Class.BitPack.Internal Clash.CPP Clash.Examples.Internal
    Clash.Signal.Bundle.Internal Language.Haskell.TH.Compat
    Paths_clash_prelude

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-prelude-1.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-prelude-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/clash-prelude-1.4.3
hs-libraries:         HSclash-prelude-1.4.3-KR9rpKHRl4oCqgtezBTxwo
depends:
    QuickCheck-2.14.2-8squlTcK6MZAcxqLTZHpKw array-0.5.4.0
    arrows-0.4.4.2-1nyLhOjVcSS8hwzfIHJR2Y base-4.15.1.0
    bifunctors-5.5.11-F7cmRR0VFpeUlKs0LdeqK binary-0.8.8.0
    bytestring-0.10.12.1 constraints-0.13.1-4ueLwpE7z3JISEn7aVhQa1
    containers-0.6.4.1 data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO deepseq-1.4.5.0
    ghc-bignum-1.1 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.3-7amvmW6WRLQ4DnvDcDYvIB
    ghc-typelits-knownnat-0.7.6-2O0UPZsU1FM9mNXCMdOOvL
    ghc-typelits-natnormalise-0.7.6-HJYGKLzoWvWF2yDRF9saDM
    half-0.3.1-4tjuzZLUBfdxjjy3bYfob
    hashable-1.3.5.0-8uEDmbS1YdCBqBDHH62nE1
    interpolate-0.2.1-G8b7ZaaENR32sJx6rPZwF2
    lens-5.1-90rUFaXMNykIIo8x6oLg1g
    recursion-schemes-5.2.2.2-FNjuH66Zivx3iSLfhn7UD2
    reflection-2.1.6-30W7EscdGAZHauAtvLUOBT
    singletons-3.0.1-6PuvKSShBybAJFkjCueV3T template-haskell-2.17.0.0
    text-1.2.5.0 text-show-3.9.2-B3QpkRroHhzI534uRHBXGK
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou
    th-lift-0.8.2-1vUj2DyOulyLmPdD5MUXBm
    th-orphans-0.13.12-DFw4doNNcmmCwMJqdDSJxw time-1.9.3
    transformers-0.5.6.2 type-errors-0.2.0.0-GpJn83wBnAVEU3sWAm5MVs
    uniplate-1.6.13-5akGFXs76zoAyIHha43xe9
    vector-0.12.3.1-AuXeyw9aHek8rgyiKRxwpj

haddock-interfaces:
    /usr/share/doc/haskell-clash-prelude/html/clash-prelude.haddock

haddock-html:         /usr/share/doc/haskell-clash-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

